@@ -68,7 +68,7 @@ class Extractor(object):
             extractor = GroupExtractor(self)
         elif self.export == 'INTERACTIONS':
             extractor = PostExtractor(extractor=self, since=self.since, until=self.until)
-        return 'aaaaaa1'
+
         logging.info(f'Extracting posts from')
         await extractor.extract()
         logging.info(f'Extraction of posts finished')
@@ -82,10 +82,12 @@ class Extractor(object):
 
             extractor.create_network_plot()
 
-
         logging.info(f'Converting to Pandas')
         nodes_pd = extractor.nodes.to_pandas(self)
         logging.info(f'Done converting to Pandas')
+
+        return nodes_pd.at[0, 'name']
+
         return nodes_pd
         # if a name for the csv file was passed, save the posts in csv format
         if self.csv:
